==> haskell-fdo-notify-0.3.1-888-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-fdo-notify.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 fdo-notify
version:              0.3.1
visibility:           public
id:                   fdo-notify-0.3.1-8a95SAqs37N9pwZNbeejg4
key:                  fdo-notify-0.3.1-8a95SAqs37N9pwZNbeejg4
license:              BSD-3-Clause
maintainer:           max.rabkin@gmail.com
author:               Max Rabkin
homepage:             http://bitbucket.org/taejo/fdo-notify/
synopsis:             Desktop Notifications client
description:
    A library for issuing notifications using FreeDesktop.org'\''s Desktop
    Notifications protcol. This protocol is supported by services such
    as Ubuntu'\''s NotifyOSD.

category:             Desktop
abi:                  8470b7278d46d22e32578b1ea3141c10
exposed:              True
exposed-modules:      DBus.Notify
import-dirs:          /usr/lib/ghc-9.4.8/site-local/fdo-notify-0.3.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/fdo-notify-0.3.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/fdo-notify-0.3.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-fdo-notify
hs-libraries:         HSfdo-notify-0.3.1-8a95SAqs37N9pwZNbeejg4
depends:
    base-4.17.2.1 containers-0.6.7 dbus-1.3.3-DxwQecE0J4QHGHdMDtxYGB

haddock-interfaces:   /usr/share/doc/haskell-fdo-notify/html/fdo-notify.haddock
haddock-html:         /usr/share/doc/haskell-fdo-notify/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-fdo-notify-0.3.1-909-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-fdo-notify.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 fdo-notify
version:              0.3.1
visibility:           public
id:                   fdo-notify-0.3.1-90MyHNj37bd3nDmEvXJxwy
key:                  fdo-notify-0.3.1-90MyHNj37bd3nDmEvXJxwy
license:              BSD-3-Clause
maintainer:           max.rabkin@gmail.com
author:               Max Rabkin
homepage:             http://bitbucket.org/taejo/fdo-notify/
synopsis:             Desktop Notifications client
description:
    A library for issuing notifications using FreeDesktop.org'\''s Desktop
    Notifications protcol. This protocol is supported by services such
    as Ubuntu'\''s NotifyOSD.

category:             Desktop
abi:                  738fbc992de79cb8ea8fa410992fe972
exposed:              True
exposed-modules:      DBus.Notify
import-dirs:          /usr/lib/ghc-9.4.8/site-local/fdo-notify-0.3.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/fdo-notify-0.3.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/fdo-notify-0.3.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-fdo-notify
hs-libraries:         HSfdo-notify-0.3.1-90MyHNj37bd3nDmEvXJxwy
depends:
    base-4.17.2.1 containers-0.6.7 dbus-1.3.3-LpDQHaNyiML1MRcclv9sum

haddock-interfaces:   /usr/share/doc/haskell-fdo-notify/html/fdo-notify.haddock
haddock-html:         /usr/share/doc/haskell-fdo-notify/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
